==> haskell-streaming-commons-0.1.19-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: streaming-commons
version: 0.1.19
id: streaming-commons-0.1.19-7mQQiCRY7vGE9EuJjSOuG5
key: streaming-commons-0.1.19-7mQQiCRY7vGE9EuJjSOuG5
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/streaming-commons
synopsis: Common lower-level functions needed by various streaming data libraries
description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.
category: Data
author: Michael Snoyman, Emanuel Borsboom
exposed: True
indefinite: False
exposed-modules:
    Data.Streaming.Blaze Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer
    Data.Streaming.ByteString.Builder.Class Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel
hidden-modules: Data.Text.Internal.Unsafe.Char
                Data.Text.Internal.Unsafe.Shift Data.Text.Internal.Encoding.Utf8
                Data.Text.Internal.Encoding.Utf16 Data.Text.Internal.Encoding.Utf32
abi: 9ee24e843ebd64bcd5a74a72b86efcdd
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/streaming-commons-0.1.19
library-dirs: /usr/lib/ghc-8.2.2/site-local/streaming-commons-0.1.19
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/streaming-commons-0.1.19
hs-libraries: HSstreaming-commons-0.1.19-7mQQiCRY7vGE9EuJjSOuG5
depends:
    base-4.10.1.0 array-0.5.2.0 async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd
    blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7 bytestring-0.10.8.2
    directory-1.3.0.2 network-2.6.3.4-5QQX2Kbe495F2cbHmSR7FO
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We process-1.6.1.0
    stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=987aeec331bd3d9d85b408736a8805c6
             blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7=3e7866bdfc4c145dc5858d744aeae7aa
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             network-2.6.3.4-5QQX2Kbe495F2cbHmSR7FO=1e0aca6235e9d0fee0939ce314445bf3
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY=a5f6b4f0b968fa7b1bee7784729ec9b2
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock
haddock-html: /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-streaming-commons-0.1.19-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: streaming-commons
version: 0.1.19
id: streaming-commons-0.1.19-LMV1a2oqZJtGrTNgvT03yr
key: streaming-commons-0.1.19-LMV1a2oqZJtGrTNgvT03yr
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/streaming-commons
synopsis: Common lower-level functions needed by various streaming data libraries
description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.
category: Data
author: Michael Snoyman, Emanuel Borsboom
exposed: True
indefinite: False
exposed-modules:
    Data.Streaming.Blaze Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer
    Data.Streaming.ByteString.Builder.Class Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel
hidden-modules: Data.Text.Internal.Unsafe.Char
                Data.Text.Internal.Unsafe.Shift Data.Text.Internal.Encoding.Utf8
                Data.Text.Internal.Encoding.Utf16 Data.Text.Internal.Encoding.Utf32
abi: 7c906efd25ab7fe833b04eaf441672a3
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/streaming-commons-0.1.19
library-dirs: /usr/lib/ghc-8.2.2/site-local/streaming-commons-0.1.19
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/streaming-commons-0.1.19
hs-libraries: HSstreaming-commons-0.1.19-LMV1a2oqZJtGrTNgvT03yr
depends:
    base-4.10.1.0 array-0.5.2.0 async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd
    blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7 bytestring-0.10.8.2
    directory-1.3.0.2 network-2.6.3.5-BVJHDRdh5LJ4pgucNKJkuJ
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We process-1.6.1.0
    stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=987aeec331bd3d9d85b408736a8805c6
             blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7=3e7866bdfc4c145dc5858d744aeae7aa
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             network-2.6.3.5-BVJHDRdh5LJ4pgucNKJkuJ=82fe21e10301e2e4d8701392ba21a740
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY=a5f6b4f0b968fa7b1bee7784729ec9b2
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock
haddock-html: /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
